%define tarname   xf86-video-radeonhd
%define moduledir %(pkg-config xorg-server --variable=moduledir)
%define driverdir %{moduledir}/drivers

# Git snapshots are treated slightly different from released source tarballs:
#  * Release: tag is augmented with timestamp
#  * Description contains a few things about the snapshot
#  * Source: snapshots are local files with timestamps, released source
#    tarballs come from ftp.x.org and have no timestamps
#  * ...
#define snapshot 0
%define snapshot 1

# If generating snapshot, we can add a utility which generates an xinf file.
# This might become interesting at some time in the future, when we are
# confident that we want radeonhd to handle those cards.
%define generate_xinf 0
%if %{snapshot}
#define generate_xinf 1
%endif

%if %{snapshot}
%define date 20091204
%define git_commit 98d1d5f68f5be3f9dc3cd4b483ca4bea708e1eb8
%define alphatag .%{date}git
%define tarball %{tarname}-%{version}-%{date}git
%define ship_utils 1
%else
%define tarball %{tarname}-%{version}
%define ship_utils 1
%endif

Summary:       Xorg X11 radeonhd driver for AMD GPG r[5-8]xx Chipsets
Name:          xorg-x11-drv-radeonhd
Version:       1.3.0
Release:       4.2%{?alphatag}%{?dist}

License:       MIT
Group:         User Interface/X Hardware Support
URL:           http://www.x.org/
BuildRoot:     %(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)

%if %{snapshot}
# The source for this package was pulled from upstream's git repository.
# (cf. http://cgit.freedesktop.org/xorg/driver/xf86-video-radeonhd/)
# Use the following commands to generate the tarball:
#  sh xorg-x11-drv-radeonhd-snapshot.sh
#  sh xorg-x11-drv-radeonhd-snapshot.sh --update-config
# The latter updates this spec file with the appropriate definition of %date.
# This requires git, automake, autoconf, libtool to be installed.
Source0:       %{tarball}.tar.lzma
%else
Source0:       ftp://ftp.x.org/pub/individual/driver/%{tarball}.tar.bz2
%endif

Source1:       xorg-x11-drv-radeonhd-snapshot.sh
Source2:       xorg-x11-drv-radeonhd-README.fedora

# Needs to be applied while creating dist tarball, but still be in SRPM.
Source11:      %{name}-Generate-xinf-file-for-hwdata-from-rhd_id.c.patch

# Patches 100-199: Fedora adaptations

# Upstream does not install rhd_conntest, but we do. Adapt docs accordingly.
Patch100:      xorg-x11-drv-radeonhd-Fix-location-of-rhd_conntest-in-msgs.patch

# Abort driver init and Xorg startup when KMS is enabled
Patch110:      xorg-x11-drv-radeonhd-Fail-PciProbe-if-KMS-is-enabled.patch

# 200-299: Misc patches

ExcludeArch:   s390 s390x

# EL5 does not have pkgconfig in default buildroot. Does not hurt others.
BuildRequires: pkgconfig

%if %{ship_utils}
# Required for building rhd_conntest
BuildRequires: pciutils-devel
BuildRequires: zlib-devel
%endif

BuildRequires: xorg-x11-server-sdk  >= 1.1
Requires:      xorg-x11-server-Xorg >= 1.1

# Avoid buggy xrandr (xorg-x11-server-utils is installed anyway for gdm)
%if 0%{?fedora} >= 8
Requires:      xorg-x11-server-utils >= 7.3-2
%endif

# Avoid ABI issue in Fedora 12 and later
%if 0%{?fedora} >= 12
BuildRequires: xorg-x11-server-sdk >= 1.6.99.1
Requires: xorg-x11-server-Xorg >= 1.6.99.1
%else
BuildRequires: xorg-x11-server-sdk < 1.6.99.1
Requires: xorg-x11-server-Xorg < 1.6.99.1
%endif

# DRI support
BuildRequires: libdrm-devel
BuildRequires: mesa-libGL-devel
BuildRequires: xorg-x11-proto-devel
%if 0%{?fedora} >= 12
# F12 moves some header files from xorg-x11-proto-devel to libXext-devel
BuildRequires: libXext-devel
%endif


%description
X.org X11 radeonhd driver for AMD GPG r5xx/r6xx/r7xx/r8xx Chipsets.
%if %{snapshot}
This package is a snapshot of a work in progress. You may experience
regressions, bugs, errors, broken displays, and other undesirable phenomena.

radeonhd mailing list: http://lists.opensuse.org/radeonhd/

Built from git commit: %{git_commit}
%endif

%prep
%setup -q -n %{tarball}
%if %{snapshot}
%patch100 -p1 -b .conntest-docrefs
%patch110 -p1 -b .kms-check
%endif
sed -i 's|\(built from %%s\)\\n\\n"|\1\\n\\tFedora package %{name}-%{version}-%{release}\\n\\n"|' src/rhd_id.c

%build
%{configure} --with-xorg-module-dir=%{moduledir} --disable-static --disable-shave
%{__make} %{?_smp_mflags}
%{__cp} -p %{SOURCE2} README.fedora
%if %{ship_utils}
%{__cp} -p utils/conntest/README README.rhd_conntest
%endif
%if %{generate_xinf}
./src/print-xinf-data > radeonhd.xinf
%endif

%install
%{__rm} -rf "%{buildroot}"
%{__make} install DESTDIR="%{buildroot}"
%{__rm} -f "%{buildroot}%{driverdir}/radeonhd_drv.la"
%if %{ship_utils}
%{__install}    -m 0755 -d                          "%{buildroot}/%{_bindir}"
%{__install} -p -m 0755 utils/conntest/rhd_conntest "%{buildroot}/%{_bindir}/rhd_conntest"
#%{__install} -p -m 0755 utils/conntest/rhd_dump     "%{buildroot}/%{_bindir}/rhd_dump"
%endif
%if %{generate_xinf}
%{__install}    -m 0755 -d            "%{buildroot}%{_datadir}/hwdata/videoaliases"
%{__install} -p -m 0644 radeonhd.xinf "%{buildroot}%{_datadir}/hwdata/videoaliases"
%endif

%check
%{__make} check || %{__make} check VERBOSE=yes

%clean
%{__rm} -rf "%{buildroot}"

%files
%defattr(-,root,root,-)
%doc README COPYING
%doc README.fedora
%doc ChangeLog
%{driverdir}/radeonhd_drv.so
%{_mandir}/man4/radeonhd.4.gz
%if %{ship_utils}
%doc README.rhd_conntest
%{_bindir}/rhd_conntest
#%{_bindir}/rhd_dump
%endif
%if 0%{generate_xinf}
%{_datadir}/hwdata/videoaliases/radeonhd.xinf
%endif

%changelog
* Fri Dec 04 2009 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.3.0-4.2.20091204git
- Abort driver startup if kernel modesetting (KMS) is enabled
- New snapshot (upstream commit 98d1d5f68f5be3f9dc3cd4b483ca4bea708e1eb8):
  - 98d1d5f6: Blacklist: Marking 0x9710, 0x1043, 0x83A2 hotplug unusable.
  - f7aed406: conntest: Update PCI ID list.

* Thu Nov 12 2009 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.3.0-3.15.20091112git
- Skipping the 1.3.0 release due to a838114e and probably other fixes.
- New snapshot (upstream commit 6387ab4c1d0ff71e556b1c96f21b4e765a6c8e5a):
  - 6387ab4c: PM: Validate known good configurations as well.
  - d6b47183: Correct copyright information.
  - d0b936db: Change wording for amount of mapped memory.
  - 5a01ea3d: DMS59: Marking 0x7183, 0x1002, 0x0D02 as such.
  - 6a2c0f04: AtomBIOS/PM: Add size checks to Voltage Info parser.
  - 2949564e: AtomBIOS/PM: Detect wrong size value in VoltageObj table.
  - fb1f84dd: DRI: Get number of pipes from DRM if possible.
  - 40fa33f0: 2D/3D: Fix Lockups on R5XX when running DRI clients with EXA/Textured Video.
  - f3df2394: Accel: Insert proper waits for 2D/3D engine idles when switching between the two contexts.
  - af5f1e1a: I2C: Fix I2C readout.
  - a76cee0a: Scaler: Add support to send TV mode the HW scaler.
  - 737f2591: Backlight: Some cosmetics to ACPI backlight support.
  - 209505b3: Backlight: ACPI backlight support for FreeBSD
  - 5cd4cca8: Monitor/Panel: Move mode line sanitization code.
  - 5092f153: Mode: Be more verbose on reporting mode rejections.
  - cee33c18: DIG: Improve code readability by using names for bits.
  - 8b89b94d: Add Fallback DAC Load Detection Method for chips >= RV620.
  - 7f896dee: Print out value of MC status register if it is busy when tested.
  - a838114e: Fix backlight readout thru AtomBIOS.
  - eef20d73: rs880: fix gart type
  - bfb6e137: configure: Remove check for GL/gl.h
  - 34d975db: Fix compilation with xf86_ansic.h
  - 42a81085: pm: Recalculate I2C clock on engine clock setting.
  - 8cbff7bf: Bump to 1.3.0. Update README.
  - bd2145d8: pm: Comment out currently unused variable.
  - 5c437ecd: README.coding: Add rhd_acpi.[ch] and atombios_rev.h
  - 0c8cc053: i2c: Hardware may need a while to indicate availability to the host
  - 57b97e0f: pm: Improve wording of lowPowerModeEngineClock logging.
  - a1cd56dd: pm: Ignore validation when setting negative engine/mem frequencies.
  - 5d5d8e3d: pm: Use minimum known working frequency instead of default/2.
  - 0a94f8eb: pm: Do NOT set idle engine clocks to default/2 unless ForceLowPowerMode is used.
  - eebdbf0a: Improve DAC load detection on RS780.
  - 422ac06b: Silence audio stream option.
  - 3cef2a65: Improve test for disabled differential clock driver.
  - 392a1392: Properites: Get HW for Backlight setting on every query.
  - f695445b: LUT: Fix syntax error in 59085c4a
  - 59085c4a: LUT: Fix RHDLUTCopyForRR() not actually modifying LUT
  - 8b3561d2: ID: Added quirk entry for HIS Excalibur Radeon XT1650 Pro IceQ 256M
  - 0a79a28c: PM: Removed unnneeded define.
  - 4758ba31: Add ACPI controlled Backlight support for Linux.
  - be7216fc: randr: Select virtual large enough for typical dual-monitor situations
  - b9648ff4: RV740: Choose shadowfb by default.
  - eb1fc6c0: Fix missing parenthesis.
  - 136dbca7: Disable DRI by default if shadowfb is explicitly selected.
  - 209aa4c7: RV740: disable DFS and Composite
  - 21f033c1: Add quirk table entry for Wyse R-Class.
  - ee508b37: Hide README, radeon.man non-updates if --enable-shave

* Fri Sep 18 2009 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.2.5-3.14.20090918git
- New snapshot (upstream commit b7a50a6f00bb6d207f5240f00cf83fbbd56bbf60):
  - b7a50a6f: Fix RHDRegWrite macro invocation breakage

* Fri Sep 18 2009 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.2.5-3.13.20090918git
- configure with --disable-shave (we occasionally need to debug the build)
- Add Xorg ABI dependency for F12 (1.6.99.*), removing the one from F9
- Update README.fedora with new chipset support
- New snapshot (upstream commit ae41ab2fe49ca456c4fb23859af8683c32c2429c):
  For details, run git log. Short summary:
  - DRI/DRM/EXA used by default on R5xx, R6xx
  - Some support for R7xx, R8xx
  - Some NULL check and logic fixes
  - xextproto 7.1 support
  - and more

* Wed Jul 29 2009 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.2.5-3.11.20090714git
- F12 moves some header files from xorg-x11-proto-devel to libXext-devel

* Mon Jul 27 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.5-3.10.20090714git
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Jul 15 2009 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.2.5-2.10.20090714git
- compile with DRI support again (add mesa-libGL-devel build requirement)

* Tue Jul 14 2009 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.2.5-2.9.20090714git
- New snapshot (upstream commit bc42c63d0cf7756a9d31c16d68d1c33a9e225b83):
  For details, run git log. Short summary:
  - Build fixes
  - initial power management support
  - man page improvements
  - misc bugs fixes

* Sat Apr 11 2009 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.2.5-2.8.20090411git
- Updated README.fedora with new feature set (2D+XVideo on R[67]xx)
- This snapshot is the 1.2.5 release.
- New snapshot (upstream commit cb54f48b212d5ae54e13bbdf24575b6163798c0d):
  - cb54f48b: Bump to 1.2.5. Updated README.
  - 9d2a5088: Fix resume from suspend for r6xx/r7xx
  - 1137e096: RHDDRIGetIntGARTLocation is called too often to be logged. Nuked RHDFUNC there.
  - 76d6973a: man: R6xx and R7xx 2D possible now.
  - 00656976: LUT: reduce number of writes to DC_LUT_RW_INDEX
  - 6d7f2486: Use () in macro arguments of new RHDRegMask.
  - d6c37277: CS: Replace register read/write macros with ones from compiler.h
  - c9d1af91: Use X MMIO macros instead of own register read/write functions
  - f65014d8: Add RV790 (HD 4890) Support
  - 79efc609: AtomBIOS: Fixed wrong logic: switch -> if.
  - ecd61667: rhd_dump: fix error introduced by LUT dump addition
  - 7e4948a3: R6xx/R7xx EXA: rework composite pixel shader
  - 461701c6: R6xx/R7xx: clean up bool const code
  - cc6e6fe4: add new chip ids
  - f0f640f1: R6xx/R7xx EXA: fix maxPitchBytes
  - 37da5e5a: Add new pci ids
  - 4fa65062: Really disable UTS/DFS on r6xx/r7xx AGP
  - b075ec9c: R6xx/R7xx AGP: disable gart data transfers
  - d9c8f9ce: r600: reload shaders into VRAM on resume
  - 12611c8f: R6xx/R7xx shader: Fix OFFSET_[XYZ] macro for TEX_DWORD2 to accept floats
  - 70490504: RS600: fix page table size for rs600 as well
  - 10ebf657: r600: fix sizing of PCI GART table for r600
  - f27383df: R6xx/R7xx: Fix OFFSET_[XYZ] macros for negative values.
  - 827fb141: randr: Set use_screen_monitor correctly using helper function.
  - 76490dd8: Enable DRI by default on R5xx chips.

* Fri Mar 06 2009 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.2.4-2.4.20090306git
- New snapshot (upstream commit 093e5934a26f784f70b5febf8ae6d50a3459552c)
  Mainly includes the R6xx/R7xx acceleration stuff (no 3D, that depends on mesa).
  Detailed changelong: "git log 047bd705..093e5934" (much too long for here)

* Thu Feb 26 2009 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.2.4-2.3.20090226git
- Change snapshot compression method to lzma (from bzip2)
- New snapshot (upstream commit 047bd7059bcfec55e06a35db4a2b16d52fe8dbf6):
  - 047bd705: EXA: fix for (incompatible) upstream EXA version 3.
  - ad6c789a: (Hopefully) fix cursor corruptions, at least on some configs. fdo #13405
  - c7735333: Fix some warnings.
  - a5a7b085: Fix warning: only compile rhdRRCrtcSetOrigin() if required for RandR 1.3.
  - 368bb0d7: LUT: Fix incorrect shifts and masks for 15- and 16-bit depth
  - 4d208cdd: Fix LUT precision handling for 8, 24, and 32bit depth
  - 6e71f01f: rhd_dump: add LUT printing support
  - ed86b90a: Add missing definition of atom_Panel.
  - b76bfbd7: Add 'force-shadowfb' AccelMethod. For testing purposes only.
  - 95aa9113: AtomBIOS: Fix build for build w --disable-atombios-parser.
  - c349a523: Trivial typo in properties / man page.
  - 68c317da: Unify and fix quirk table macros.
  - e216e686: Add quirk table entry for HIS Radeon X1550 PCI.
  - f45e95cc: build: catch incompatible options in configure
  - e738e579: Quirk for PowerColor HD 3450.
  - 127d362c: I2C: Fix NULL pointer deference spotted by Maciej Cencora.
  - 1652f150: Build: Fix build when AtomBIOS subsystem is disabled.
  - a981e2d0: Remove xorgconfig & xorgcfg from See Also list in man page
  - f57a410c: Fix scaling documentation.
  - 44720209: RS780: set bustype to PCIE
  - 421edfd7: MC: Fix warnings and streamline naming of MCGetFBLocation.
  - 28956656: Card quirks: fix warning introduced in b2e2693d
  - 5eed0c4f: ID: add 0x944C (RV770).
  - b2e2693d: Add quirk table entry for GeCube Radeon HD 2400PRO
  - 003325a5: Implement RandR 1.3 mandatory properties.
  - 33bf07be: Renamed properties according to RandR 1.3 property guideline.
  - c990d6d7: Typo fix in man page
  - 107c97a6: Change all gitweb URL references to cgit
  - 0b47e600: man page: Add R7xx to NAME section
  - d46d50e6: MC: Pass FbLocation and FbSize to RHDMCFBLocationSetup().
  - 0fd284c0: MC/Idle: ASSERT() the right setup order, don't change an unidled MC.
  - eeb66dc9: MC: Refactor MC code.

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.4-2.2.20081212git
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Mon Dec 22 2008 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.2.4-1.2.20081212git
- Force rebuild on rawhide aka F-11.
- Change obsolete gitweb references to valid cgit references.

* Fri Dec 12 2008 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.2.4-1.1.20081212git
- Upstream have released 1.2.4 today. This snapshot is 1.2.4.
- New snapshot (upstream commit 4e8972638db59d007bc61eb1bef8adb99cc67000):
  - 4e897263: Bump to 1.2.4
  - 2db9ee5e: Add release information for 1.2.4
  - 9cdbad32: Nuke description of option "ShadowFB" (not existing any longer).
  - 0679ce59: Small manpage updates.
  - 7aae5f7f: FB mapping: Restore original PCI MapSize if IGP memory mapping failed.
  - 6c91fed6: Workaround for drm header mismatches (DEPRECATED and __user on Fedora 10)
- Disable spec file workaround for undefined DEPRECATED and __user macros.

* Sat Dec 06 2008 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.2.3-1.7.20081206git
- New snapshot (upstream commit 48def66ce9592926ed9b23530fb21a55ac253392):
  - 48def66c: Document that Option "DRI" also affects Xv
  - de7a4147: R5xx XAA: pass correct size to xf86InitFBManager.
  - 46df4169: RandR 1.3 Panning support
  - 907365c7: RandR 1.3 Panning support
  - ae56abc1: RandR: Improve heuristics to determine of an output is connected.
  - ed532a70: ID: Add connector table for HD 2400 "0x94c3:0x000:0x0000".
  - 69eadbf2: ID: Supply fixed connector table for  Radeon X1300 0x7187:0x1545:0x1930.

* Fri Nov 28 2008 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.2.3-1.6.20081128git
- New snapshot (upstream commit 8edc0c698bc225a0581d4e17820f28efb4db97df):
  - 8edc0c69: BugFix for RandR cursor interface
  - 48f9d1af: DIG: Remove stray ErrorFs
  - 078842c7: ID: 0x7187:0x1458:0x215C has a  DMS59 connector.
  - dc81290f: Rotation: document limitations in man page.
  - d4c49758: Rotation: NULL callbacks to rotation functions if no HW acceleration is enabled.
  - 66f4a3a6: Rotation: Don't allow to set a PANNING_AREA when rotated.
  - 5b9ef245: Rotation: Fix up Crtc base pointer.
  - 23bc497c: Rotation: Remove USE_XAA which had been left over from rebasing.
  - 24ba47d9: RandR: Some minor cleanup.
  - e304e561: HW Cursor: Add RandR cursor interface.
  - c1827740: RandR: Add screen rotation.
  - 41d4bf71: RandR: Initialise the LUT on a new CRTC.
  - c2dfeafe: DRI: Bail DRILeave/EnterVT() when drmFD == -1.
  - def3c1f5: DIG: Add debug code.
  - ad876362: rhd_conntest: Make rhd_conntest work on FreeBSD.
  - 10dc7797: ID: Add HPD_OFF flag for Foxconn A7GM-S (RS780) motherboard.
  - 4d65e4c6: DRI/CS: Set drmFD to -1 after closing the device.
  - 65f01922: AtomBIOS/BacklightControl: Add destroy function for data structure and fixes.

* Wed Nov 12 2008 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.2.3-1.5.20081112git
- New snapshot (upstream commit 53dd35cb766138c879c926a8374380174e876d35):
  - 53dd35cb: DRI: Exit RHDDRIScreenInit() with FALSE when init failed.
  - a2fa612c: RandR: Bracket block properly.
  - fe4356ce: DRI: SwapContext: Stop wanton XAA syncs.
  - bb14c00c: Add RV730/710 PCI Ids.
  - ac56b4c8: ASIC_Support: Add AtomBIOS support for RV730/710 chipsets.
  - 57f11067: I2C: Add additional I2C lines for for DCE3.2 support.
  - 30f4bf2b: MC: RV770 code also supports generations beyond this.
  - 680f05ac: AtomBIOS/Backlight Control: Fix AtomBIOS based BL control for hardcoded outputs.
  - d125c0fa: DIG: Add debug output for EncoderPower().
  - 264a8b5f: DIG: Fix SEGFAULT with new coherent option.
  - db72b6a5: Coherent: Update man page to match Christian Koenig's fixes to the option parser.
  - 36657dc3: Use RhdParseBooleanOption for ignoreconnector config option
  - 2e3590da: Use RhdParseBooleanOption for HDMI config option
  - 908fabd6: DIG: Add RHD_OPTION_NOT_SET to dig outputs.
  - 08fedbb6: Fix and improve RhdParseBooleanOption.
  - 3036b40f: Output/Coherent: Fix bug in parser, add man page.
  - 75b4f1d2: Don't allocate framebuffer for cursor images if software cursor is used.
  - f29a3d2f: DIG: Don't disable encoders which are assigned to active connectors.
  - 72aaf9bd: DRI: Keep rhdDri struct for server lifetime.
  - c3e4ef7f: MC: Consolidate rhdAllIdle() and RHDModePrepare().
  - ec67c56c: Move MC setup before DRI init. Fixes issues DRI issues on some systems.
  - 8676c233: DIG: Add debug output to inform about probed encoder mappings.
  - 6e40d3b9: Add config option for coherent settings on digital outputs.
  - 6b76953c: Option: Add handling for option containing a string of boolean settings.
  - 9ca2384d: BIOSScratch: Treat DAC SENSED_NONE as CRTC output.
  - 1292ab01: Option: Add handling for option containing a string of boolean settings.

* Wed Oct 29 2008 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.2.3-1.3.20081029git
- README.fedora: How to adapt xorg.conf to use radeonhd
- New snapshot (upstream commit a36896dd0b44a26816ac0a401c0d9918a100d624):
  - a36896dd: AtomBIOS/Output: consolidated handling on UNIPHYA and UNIPHYB.
  - e3c56962: EXA: Move inlcusion of exa.h before xf86_ansic.h.
  - c38be243: DCE3.0: Properly map DCE3.0 DIG encoders.
  - 9e81b2cc: ID: Add PCI ID 0x95C6.
  - e589cc35: Update README and man page only if sed is OK
  - 7880b5a9: Manpage: Add Christian Koenig to the list of authors.
  - d88f685c: Fix README update on FreeBSD (sed substitution)
  - 01152def: Imake: Fix build for xvideo and hdmi audio.
  - 1e26e7a7: Autoconf: Fix RandR12 changes.
  - 0ea65a3a: Reorder source file list alphabetically
  - 3ac30d19: HDMI: Add HDMI support.
  - 69d4dabe: Autoconf: Fix build on Ubuntu Feisty Fawn.
  - 15f0b2a8: [PATCH] Link with -lpciaccess and -ldrm as needed
  - b77f9a77: autoconf: Add glproto as a dependency for DRI.
  - dff3e283: gitignore: Add some distcheck files.
  - efaebb70: Cleanup SEGV_ON_ASSERT in HAVE_XF86_ANSIC_H case.
  - 29cd7382: R5xx3D: Disable XHas3DEngineState upon VT switch.
  - 0a9a206a: CS: Remove Mask member.
  - 3f558efc: AtomBIOS: Make deviceID override table actually work.

* Tue Oct 14 2008 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.2.3-1.2.20081014git
- New snapshot (upstream commit e7abdfc07e16c961767dbff72ddbb12cb5af9677):
  - e7abdfc0: Xv: Fix build for big endian.
  - 416eb952: Add HDPSWAP for Gigabyte GV-RX16P256DE-RH.

* Mon Oct 13 2008 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.2.3-1.1.20081013git
- Upstream have released 1.2.3 today. This snapshot includes 1.2.3.
- Update README.fedora with new features.
- New snapshot (upstream commit 28233dcd2729c9339fd97e63df595aebb3bb0f5d):
  - 28233dcd: Add Alex to authors list in radeon manpage.
  - 57aca005: Bump to 1.2.3.
  - 7aa72401: CS: Xv: clean up memory handling.
  - 13a6774a: CS: Port over textured video support.
  - 28f2ff1b: CS: Port over EXA code.
  - 5b3eacc4: CS: Port over and enable XAA.
  - ec6d1e78: CS: introduce Command Submission infrastructure.
  - 3a56eb0c: Bump to 1.2.2.
  - 50a02b9a: Update README and man page.
  - ffcb67f3: Remove deprecated RRUseXF86Edid option.
  - 44d2dc94: AtomBIOS: Disable AtomBIOS based backlight support for the hard coded path.
  - 6612a836: I2C: Fix I2C line ID.
  - de58929f: Add the HPDOFF flag to 0x71ce, 0x18BC, 0x2770.
  - 67420d01: AtomBIOS: Some fixes to the option parser.
  - c4876e9b: Output: hook up AtomBIOS Backlight control if native method is not supported.
  - 4bba1163: Fix two warnings.
  - ec287ae3: Fix ASSERT() handling for good.
  - 1668f1f1: abort() needs stdlib.h
  - 0fd255db: Don't call xf86abort() if HAVE_XF86_ANSIC_H is not true
  - 0779c47e: DDC: Make GPIO to DDC line mapping more verbose.
  - 299a6c86: atombios.h and ObjectId.h updates from upstream
  - 4dcc6aa0: git_version.sh: Debug failure to find .git/ dir
  - 72feab0a: Pre-CS: radeon_commonfuncs.c got renamed to radeon_3d.c.
  - 52d7dced: Pre-CS: Make shared code build in master.
  - f4cbf1d5: AtomBIOS/Output: minor code cleanup.
  - 4d14b581: AtomBIOS: Adding support for an override AtomBIOS deviceID table.
  - f7dcc26f: BIOSScratch: Handle missing AtomBIOS device ID more graceful when using quirks table.
  - 79efadf6: Connector: beautify print message.
  - abb5fe6c: RandR: Print out driver supplied modes in debug mode.
  - 030da51f: DAC: Reset FMT register on DCE3 when output is DAC.
  - a0de2f58: AtomBIOS: Fix test for AtomBIOS usage.
  - 3c252c2a: Comment/typo fixes in README update rules
  - dea5cfcd: README: Move build/install docs to INSTALL file
  - a853fe26: README: Add automatically updated chipset list
  - e5a8d7fc: README: Fix list of sections

* Wed Sep 17 2008 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.2.1-3.9.20080917git
- Fix build on rawhide/F10 by defining cpp macros __user and DEPRECATED
- New snapshot (upstream commit 07408e8518e4e19663c109ea8ad765686ea4e01e):
  - 07408e85: AtomBIOS: Fail driver instance if AtomBIOS mode setting is requested but no BIOS image found.

* Sat Sep 06 2008 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.2.1-3.8.20080906git
- New snapshot (upstream commit f1c6cc865d8d0703478c3eedea2e706e911f9965):
  Upstream has merged their QnD and AtomBIOS branches to master a
  few weeks time ago, so there are way too many changes to list here.

* Thu Jul 24 2008 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.2.1-3.7.20080724git
- New snapshot (upstream commit 31e46386293fd0c54c99328eee3cfe7b49584f9d):
  - 31e46386: Connectors: Increase the number of available connectors to 6.
  - 8b1d3323: I2C: Fix I2C slave address probing for RV620 and later.
  - d65b67b0: HPD: Add support for HPD_3 found on RV620 and later hardware.
  - a900052b: DIG: Extend heuristic to check if golden values are available for requested coherent/incoherent mode.
  - d3e6c7f7: RandR: Log when a 'scaled to' mode doesn't vaildate.
  - 68592e30: MC/RS600: Fix MC indirect access functions.
  - fdf5014c: CRTC/Scaler: Log more information about the scaler.
  - 94d759b9: DDIA: Disable Sync DC Balancer on DDIA block of RS690.
  - 202f2332: I2C: Check for more error conditions in I2CStatus on RS690.
  - ec2fbeee: Fix typo in list of supported chips (again)
  - 435320de: Crtc/Scaler: Disallow interlaced for all modes involving scaler.
  - c0e0dc7d: ID: Adding M82 chipset name and some more verbose logging info.
  - 8133d1a4: MC: Enable MC control for RS600, fixed segfault.
  - f362e5ab: R5xx DRI: increase CP timeout.
  - 1761d6c5: R5xx Accel: split r5xx2DInfo into XAA and EXA specific structs.

* Sat Jul 19 2008 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.2.1-3.6.20080719git
- Compile DRI support.

* Sat Jul 19 2008 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.2.1-3.5.20080719git
- New snapshot (upstream commit 603a35a670c71d32c4f393e21ed09f87449ebbf6):
  - 603a35a6: Fix typo in list of supported chips
  - 3bc154bf: ID: Remove concept of chipset families.
  - 3ac5a2f5: ID: Update list of supported chipsets, bring in sync with chipsets listed.
  - edb72452: MC: Make sure MC engine is all idle before setting up the MC.
  - 4eebf4bc: Define SED var without requiring AC_PROG_SED
  - 2bc4450a: Use 'git foo' instead of 'git-foo'
  - 4134177e: Automatically update man page from rhd_id.c
  - b3717c77: I2C: Fix typo that caused one DDC line to not work properly.
  - bd14f735: Add proper MCIdle() bits for r6xx/r7xx
  - 72477c9e: manpage: Add description on the scaling option.
- Fix removal of build dir in snapshot script

* Wed Jul 16 2008 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.2.1-3.4.20080716git
- New snapshot (upstream commit 820187b208ab1ec94a015f07e48abbb381524c89):
  - 820187b2: Fix hangs when setting up the MC

* Sun Jul 13 2008 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.2.1-3.4.20080713git
- Note Fedora package version in radeonhd's Xorg.N.log output.
- Snapshot generation updates spec file now
- New snapshot (upstream commit 8326ff4fb3d2fff74b11a5391b74866a656380ff):
  - 8326ff4f: MC: Add a stub for RV770 MCIdle().
  - c6dcd8d1: conntest: Add support for RV770 to rhd_conntest.
  - 20476754: I2C: Add DDC read out support for DDC3/4.
  - 49b3782f: I2C: Read SDA/SCL mapping for RV620 and up from AtomBIOS GPIO Info block.
  - 4b7ce33f: Add initial support for RV770
  - 9b388fb0: DIG: Add support for ATOM_TRANSMITTER_CONFIG_LINKA_B/B_A.
  - c258c35f: conntest: test more error conditions.
  - 45961a0c: sh cmd substitution w/ backticks until git found
  - 31d76dab: Document more names for xorg/util/macros packages
  - fde79f9b: Add XORG_* macro names to docs for easy grepping
  - d44b0def: Name drivers dir "driversdir"
  - 7b3bd157: Disable unnecessary libtool CXX and F77 checks
  - cd4ed275: Fix typo in git format-patch instruction

* Mon Jun 30 2008 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.2.1-3.3.20080630git
- New snapshot (upstream commit c2139d8c7aed128644dcb1481426164ece0b967d):
  - c2139d8c: R5xx Accel: another 2DFlush fix...
  - dbc7057d: R5xx EXA: Destroy Nulls the XAAInfo... Oops...
  - 5fe51b2e: r5xx accel: bring 2DFlush and engine initialisation into the r300+ era.
  - 85ae6e1b: r5xx accel: move r5xx_2dregs to r5xx_regs.c.
  - 39209b36: rhddump: bail out correctly when no pci-tag is provided.
  - 10d5a41d: DAC: Program TV mux only for DACB.
  - 7825387b: CloseScreen: Fix test for AccelMethod.

* Sun Jun 22 2008 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.2.1-3.2.20080622git
- Proposed fix for bugs #451349 and #452050 (commit a67a65eb)
- New snapshot (upstream commit 1eff3e783bf6cab33dad837ec0c4edc07d967f7c):
  - 1eff3e78: CONNTEST: Added new PCI Ids.
  - 372c5905: ATOMBios: Fix bogus log message.
  - a67a65eb: MC: Add sanity check for IGP FB location.
  - c38112c8: VRAM Fix clamping to aperture.
  - 2bfccf62: Add more verbose debugging information.
  - 74cb0fc6: Free data structures on close screen to avoid memory leak.
  - 47ba86d6: Add a bit of info to the README to help FreeBSD users who are having  trouble building the driver.

* Wed Jun 18 2008 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.2.1-3.1.20080618git
- New snapshot (upstream commit 1f65f354cfdda40578b222beb1dd6a48af451735):
  - 1f65f354: MC Fix build.
  - 357e232a: Add test for sideport memory on IGP.
  - 88e0c878: MC Add optiuon to turn off chipset features that have not been verified by ATI.
  - c6e75506: DIG,RS780 Fix test for LVDS/TMDS.
  - 6623271d: MC,RS780 Set the correct write enable bit for MC write access.

* Fri Jun 13 2008 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.2.1-2.20080613git
- New snapshot (upstream commit ad59f09e3e30f5aafbd29a07f1078c2293847ad6):
  - ad59f09e: MC: HDP_FB_LOCATION on R5xx is direct MMIO not indirect thru MC.

* Thu Jun 05 2008 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.2.1-2.20080605git
- New snapshot (upstream commit 26ccf1177465beb2db5a2c972dd7adc17c3f457b):
  - DRI support on R5xx (X1000 series)
  - Lots of other updates, too many to list them all.

* Tue Apr 29 2008 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.2.1-1.1.20080429git
- Fix segfault in some configurations (commit 71ec0c90) (#439046)
- New snapshot (upstream commit 45fdec79e523f3f9637c35a3d84c1fd9e61b9b21):
  - 45fdec79: R5xx TMDSA: Power: don't clobber UNKNOWN when going in RESET.
  - c2a844ca: LVTMA: always use IDCLK for transmitter.
  - 9d489911: Add proper fallbacks for I2C timing if clock information from AtomBIOS isn't available.
  - 71ec0c90: Limit mapped fb size to available VRAM, clamp VGA save/restore to mapped fb size.
  - 0697b366: Add a test for __GLIBC__ to CD_Common_Types.h.
  - 19e4011e: Add connector table for 0x7183, 0x1092, 0x3000.
  - e3d1a63a: Fix flickering thru DPMS on TMDSA, improve debug messages for output Power().
  - 686fd334: Add fallback to rhd_conntest to work when AtomBIOS isn't available.
  - 38e7a912: Add better debugging output for VGASave().
  - 6f34607b: Fix mapping flags for FB when using libpciaccess.
  - 10ebfdbc: Adapt to API changes in current upstream X.
  - db8aa081: Add register write to dumper.
  - 0dd39c82: Clamp the size of VGA memory to read to not read past the end of the framebuffer.
  - 0442f2d5: Don't use chipset based backlight control when not enabled at startup.
  - df83b56a: Improve DAC load detection.
  - 420a4b10: Fix backlight and coherent property for RandR 1.3.
  - 84bf6a2a: Remove debugging code that was accidentally committed.
  - 0ffd41e0: Remove call to alloca().
  - bdea7eba: Fix up function name for RHDReadPCIBios().
  - b6bec02e: Replace reverse engineered PCI BIOS ROM enable code for R6xx.
  - e65e6c00: Fall back to reading the PCI VBIOS when reading from legacy location fails.
  - cf87d316: Fix a segfault in the DIG block.
  - b6be09ff: Save/Restore backlight controls, obtain initial brightness from text mode.
  - 3893c621: Add backlight support to RV620/635 DIG transmitter blocks.
  - 5fccf420: Add support for coherent mode for digital outputs to rhd_randr.c.
  - d401bf8f: Add 'coherent' property for DIG (UNIPHY/LVTMA), R5/6xx LVTMA and TMDSA.
  - 54a74878: Change backlight controls to new property model.
  - 01e9dd1d: Add general output property callback.
  - a751128b: Backlight control: change some debugging output to only show in verbose log.
  - b7a2fa25: Add support to control backlight brightness thru RandR properties.
  - e4d846c9: Include alloca.h in rhd_conntest.c, fix messages in rhd_dump.
  - 725ea553: Reorder TMDSA setup/power on code. Improve TMDS PLL reset.
  - bf267c11: Add connector quirk table for Visiontek C1550.
  - a60e01c8: Fixed name "RHD_DDC_NONE" printed out to log message.
  - 6a19b519: Add missing support for HDP_FB_BASE on r5xx and rs690.

* Tue Apr 15 2008 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.2.1-1
- 1.2.1 release (upstream commit 761940fde7fef72bff18a8b8e840540452cf675a)
  - New RV670 devices added: HD 3960, FireStream 9170
  - Unsupported M86 device removed: HD3650
  - assert() -> ASSERT() fixes

* Fri Apr 11 2008 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.2.0-2
- Fix spec file snapshot/no-snapshot conditionals
- 1.2.0 release (upstream commit 9d131f9035b3b0ff7755dda708e16326aa156e83):
  - 9d131f90: Bump to 1.2.0. Add changes to README.
  - 7560240b: Update + fix supported chips list, both in source and manpage.
  - 59505016: Add a very basic register dump utility.
  - b0563cbd: Add a very basic register dump utility.
  - 89c10062: Minor cleanups.
  - bb652740: git_version scripts: add licensing information.
  - 60dc7e04: Add a hard coded connector table for an MSI HD2600PRO AGP.
  - 8048353d: Remove unneeded use of pciTag when using libpciaccess.
  - 3076447f: Fix MC access for RS 690.
  - 01bc57b1: Add initial support for talking to IGP northbridges.
  - 46367d61: Add IGP flag to chipset map.
  - 338eb58b: In verbose 7 debug mode dump present mode line.
  - c0c8fbed: Mark PCI subsystem 0x94C1, 0x1002, 0x0D02 DMS-59.
  - 5a8138e8: Treat RV635 as a separate family.
  - 954fd01c: Provide more information on HPD detection and mode programming in verbose log.
  - 4733547b: Add support for the full RS690 family including RS740.
  - 580ad5bf: Enable RS690 MC support.
  - decf3554: Treat all RV515 chips as such in MC code.
  - 2c2d1320: Add a workaround to make interlaced mode work.
  - 783b5ab4: Add support for interlaced modes.
  - 6d5ef116: Add better support for LVTMA TMDS macro control values on R5xx and RS600/RS690.
  - 38efb27c: Add MC idle testing for RV515, add MC support for RV550.
  - f64aba20: Use proper temporal dither reset bits depending on chip generation.

* Fri Apr 04 2008 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.1.0-0.9.20080404git
- Do not create fedora snapshot git branch unless necessary
- Allow changing laptop panel background brightness (#350601)
- New snapshot (upstream commit db2c3948d5a398047b3a881f6f88541dc963d22e):
  - db2c3948: Fix LVTMA code to also handle single link DVI correctly.
  - 55e3b21e: HDMI Type A is single link DVI while B is dual link.
  - d53f2201: Add source select to DDIA block.
  - be9055f0: Fixed argument order to rhdAtomGetTableRevisionAndSize().
  - 1623f86f: Added missing rhd_ddia.c/rhd_ddia.o to Imakefile.
  - 186c345c: Print output name for sensed type.
  - d7d63b25: Print sensed type also for RandR.
  - 6d628f56: Make debugging output of HPD verbose about the result.
  - 811b0cd6: Added quirk table entry for a different Sapphire X1300
  - 89cfb738: Add support for RS690 DDIA digital block.
  - b6418a97: Add debugging aids.
  - c8ad2599: Reset CRTC horizontal counter replication.
  - bd11d76a: Handle AtomBIOS TMDS PLL parameters correctly.
  - 806d9536: HDMI Type B connector is dual link capable.
  - ae3171b9: Add TMDS PLL macro control values for M54 (0x7145).
  - 19a6eb46: Chipset name review.
  - 96f36339: Fixed imake build.
  - 3d62e9a1: Cosmetics: Move RV620/635 to a more sensible position in our devices list.
  - 9de85904: RHDPLLsInit: PLL2: Add missing " else " in "if () {}{}"... Duh.
  - 00f182d6: Use correct option name for (yet unused) TVMode option.
  - 98d328b0: Fix endless loop.
  - 427d9553: If available read panel dithering parameters from AtomBIOS.
  - c336508e: Remove DVI_DUAL as a type which can be detected by load detection.
  - bf8bda88: Make variable and enum names more consistent.
  - db0d6058: Fix a memory leak.
  - 098cf71d: Make test for DIG2 more consistent.
  - 46a40c82: Add #ifdef wrappers around AtomBIOS related code.
  - 54f491f9: Add AtomBIOS based UNIPHY support for RV620/635.
  - 2d81ffc7: Fix a wrong type in ATOM_ANALOG_TV_INFO in upstream version of atombios.h.
  - cab03118: DxCRTC: Fix disabling check.
  - 52f04a7f: TMDSA: Fix sensing with respect to duallink.
  - 42d3201b: PLL: further fall-out of removal of validation callback for our hw.
  - 8f499c38: DVI is on TMDSB not LVDS.
  - 56a264f8: Set Connector element already in rhdRROutputDetect().
  - 478bda79: Fix issues with DDC on RV620/635.
  - e5dddbc2: Fix issues with DAC load detection on RV620/635.
  - 5596d06d: Fix issues with DAC load detection and erronous DDC detection on RV620/635.
  - c9ccc4c4: Resolve unknown registers.
  - aa7037a7: Remove stale structure elements.
  - dfe36048: Changed heuristics for encoder link enabling.
  - 153331e8: Properly restore Encoder and Transmitter.
  - 6742f79e: RV620: Add Pixelclock support.
  - 807e525a: Implement the hardware level scaling code.
  - fd6a7abf: Restructure FMT block handling.
  - 2e1f55b0: Consolidate handling of dual link TMDS displays.
  - f0256f38: List explicite arguments for FMT block programming.
  - 59de4071: Fix identification of end-of-code table data tables and GoldenSettings search.
  - b3df388f: Add RV620/RV635 devices.
  - c13650e6: Add KLDSKP_LVTMA and UNIPHYs to connector handling.
  - 0dee42c5: Add support for new DIG blocks on RV620/635.
  - 8dabb69a: Fix structure names in rhd_output.c.
  - 80fb6b3f: Fix copy-over artefacts from rhd_conntest.
  - 252491e4: Adding KLDSKP_LVTMA and UNIPYA/B as output types.
  - 6dab67a8: Add RHD_CONNECTOR_DVI_SINGLE to be able to mark a single link connector.
  - abb188fe: Separate query for temporal and spatial dithering.
  - 4ec30282: Add more verbose output on GoldenSettings matching.
  - a0c11368: Add support enumerated object IDs to the connector table parser.
  - b280b417: Support for TMDSA dual link load detection (untested!).
  - dec87ba6: Add support for dual link DVI panels (untested!).
  - cf8eea25: Add support for two new ObjectIDs required for RV620/635.
  - 55ce4f82: Added own version of AtomBIOS getConditionalGoldenValues().
  - 283c2d2e: Fix GPIO routing for DDC in RV620/635.
  - d499a616: Fix GPIO routing for DDC for RV620/635 in rhd_conntest.c.
  - 8de4cd9a: Locate data tables embedded in AtomBIOS command tables.
  - e29024d9: Consolidate load detection for R5xx/r6xx in rhd_conntest.
  - f021c0cf: Add support for DAC load detection and I2C for RV620/RV635 to rhd_conntest.
  - 481df402: Add stubs for the PLL subsystem.
  - 3ba1c093: Add support for the DAC output subsystem for RV620/RV635.
  - b08e64ec: Add I2C subsystem support for RV620/RV635.
  - 089801d4: Add RV620/RV635 PCI IDs.
  - 47298a34: Add support for sensing and programming different analog outputs.
  - 2d42e5b7: Add monitor support for TVs.
  - 8f06626d: Add an option to pass the TV standard to override boot default.
  - 3fe49f2a: Fix spelling of 'Supp(p)orted' to match the fixed spelling in atombios.h.
  - 2bcabe12: Add parsing of TV releated data tables to the AtomBIOS support.
  - 726f6da1: Add TV detection do DAC load detection.
  - e1605dfb: Be more verbose about fb parameters.
  - 5163b9fb: Get and store verbosity level.
  - 00e1b025: Restore original order of CRTCRestore and VGARestore.

* Sat Mar 01 2008 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.1.0-0.7.20080301git
- Add dependency on xorg server on F9 to prevent ABI compatibility issues (#431176)
- Reflect R5xx partial 2D acceleration support in README.fedora
- New snapshot (upstream commit 8c6d1b46b70ae19fafb5484c238a74cca18d5990):
  - 8c6d1b46: conntest: add new ids.
  - 294cf1f6: Fix test for RS6XX in RHDMCSetup().
  - 1b3f3c9c: Add connector table flag for X1400 (0x7145, 0x1297, 0x3058).
  - a23b1123: Loop over all CRTCs when shutting down memory access.
  - 8432cb08: Add quirk table entry for Diamond Viper Radeon X1650 Pro
  - 5ba5f4b5: Include description for acceleration options.
  - eee9b718: Fix typo in patch adding DradonFlyBSD support.
  - f89bac58: Add support for DragonFlyBSD.
  - 1223e40a: Add debugging to rhd_conntest.c
  - 1e8637b1: Changing R6XX_MC_VM_MISC_OFFSET to R6XX_HDP_NONSURFACE_BASE.
  - 854ce3b2: Make DDC for panels work on MacBook Pro's.
  - 247d4263: Set up GPIO pin HW access for DDC testing in rhd_conntest.
  - 23a47ec0: Restore VGA after restoring the CRTCs.
  - 74eacf3e: Make sure GRAPH and CRTC engine are disabled before changing surface.
  - 2b16734b: Set GPIO pins to be HW driven on R5xx for HW controlled I2C.
  - 2feff5cb: Add wait for memory idle state.
  - e0d58784: Handle LVTMA_TRANSMITTER_ENABLE identically on R5/6xx.
  - 1849092e: Add connector information for a Sapphire Radeon HD 2600 PRO AGP (PnPID: 0x9587:0x1002:0x0028).
  - 7527df07: Revert "PATCH: Report PANEL as disconnected when no modes are available"
  - 3d29d4ce: PATCH: Report PANEL as disconnected when no modes are available
  - cd6a4b89: typo fix in DPI guessing code
  - 1a503c59: Update ObjectID.h
  - 8640be8e: Update atombios.h

* Sat Feb 16 2008 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.1.0-0.6.20080216git
- New snapshot (upstream commit a9af866ae712a0048d374dc640e482d1f4ce8859):
  - a9af866a: Prevent endless loop in connector table parser.
  - 80c7c9e5: Fix device ID for 0x7187, 0x174B, 0x3000 in cards table.
  - bef7f09c: Ask people to not only send in their log file but also to describe their problem.
  - bde5fbbf: Added 'HPD swap' flag for  0x7187, 0x174B, 0x300.
  - 7606be1a: Fully implement the SaveScreen() function.
  - 748de840: VGA: bitten by pScrn->videoRam in kB instead of B again.
  - cbbd54a2: Fix blaning problem in bug #13853.
  - f37d4cb9: Don't make assumptions about DDC clk line on RS690 when AtomBIOS is not available.
  - dc519eb2: Need to include string.h in r5xx_exa.c

* Sun Feb 03 2008 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.1.0-0.5.20080203git
- New snapshot (upstream commit caa10014d115a49a59b4a2aef6ce36a4e615556a):
  - Basic EXA/XAA for R5xx
  - Add PowerColor X1550, PCP X1600 400M/500E, R680 (HD3870 X2)
  - 7cab021c: Improve FB handling
  - e0cfbcd5: Add AccelMethod Option and related handling
  - 5829bff7: TMDSA: Add control value for 71C4
  - 7cb27bca: Add RHD_CARD_FLAG_HPDOFF flag, improve quirk entries for T60p
  - 32d1b4d9: If no EDID is available, assume 96dpi on the first (preferred) mode
  - ad50eaa0: Correct order of mask and value in ROM access code
  - 0f066c20: Implemented PLL functions for CAIL, fixed MC
  - 361ba486: Change heuristics to check for an unPOSTed card
  - 72e7b062: Fix some issues when reading PCI ROM on POSTed systems
  - a412d582: Read PCI BIOS on secondary R5xx cards

* Thu Jan 03 2008 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.1.0-0.3.20080103git
- New snapshot (upstream commit 4e488a349c862da2e27f6025d376fb2b63db3bf9):
  - Enable FB location fix for r5xx.
  - Fix PLLControlTableRetrieve() loop.

* Fri Dec 28 2007 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.1.0-0.2.20071228git
- New snapshot (upstream commit fcf15c8facb7c2c1a4a2513f3f84537f3f35c6a1):
  - (Some?) RV670 support
  - c036b819: Only report unknown cards IF they have issues.
  - b9277bfc: Check for loaded fglrx kernel module.
  - 765f5972: Man page describes all RandR properties
  - 2b3928c6: Fix "messed up colours" issues after suspend/resume
  - ...

* Wed Dec 19 2007 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.0.0-0.4.20071219git
- New snapshot (upstream commit 861debbf8d649ce09d53d5880f819757ac9c7814)
  - 861debbf: Make the driver build with the latest ustream git server sources again.
  - 9120f95f: Delete a spurious git_version.h.new when doing make clean.
  - e98195bd: Don't fail immediately when git-rev-parse fails.
  - 6d9a6709: IDs: Asus M2A-VM should now no longer need a connector table.
  - 521bcace: DxGRPH: Fix graphics engine colour issues (hopefully).
  - 47f8a6f7: Add support for HDMI connectors.
  - 21e1c6c4: Get EDID block for panels from AtomBIOS even if there is a special Mode.
  - 492e94c3: LVDS: Fix 18/24 bit dithering and disable spatial dither.
  - 55f89f69: LVDS: Fix FPDI handling.
  - ef51931a: HPD pin swapping logic.
  - 9741c5be: TMDSA: properly add macro control for 0x7149 (M56)
  - dcfd91c2: TMDSA/B: add macro control values for 0x71C6 (RV530)
  - c784c92a: TMDSA: add macro control for 0x7147 (M56)
  - 5acefe5c: ID: 0x724B: Sapphire Radeon X1900 GT
  - 1a1d110f: Restore: Fix VGA textmode restore when VSYNC length is 0.

* Wed Dec 12 2007 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.0.0-0.3.20071212git
- New snapshot (upstream commit b991fe3d884a51e236f895c41b0ba1b06127f7dd):
  - b991fe3d: DACs: Properly set up and save/restore SYNC_SELECT.
  - bb12148c: Added Asus M2A-VM (RS690 based) to quirks table.
  - 87f8f8e9: Add Gigabyte HD 2600 XT to quirks table.
  - b0cb8aec: Don't check for connector type for DMS-59 detection (RandR case).
  - affbdf54: Additional checks for cursor size in UseHWCursor().
  - 09b4dea7: Only reload cursor image if there is one.
  - dc7fe476: Broken connector table: GeCube Radeon HD 2400 AGP: proper fix.
  - ae46a18d: TMDSA/B: 9587 electrical values.
  - 030f715c: Fix 13509: Xserver crash when RandR finds no modes.
  - c01edd52: Improve scanning of panning area specification. Pan to area on setting it.
  - 42a07a0d: Re-create Atoms for properties in CreateResources.
  - 6d0c7c32: Add panning in RandR mode.
- Ship new ChangeLog file.

* Sun Dec 09 2007 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.0.0-0.2.20071209git
- New snapshot (upstream commit e399d16597e30a6c53c8f70aa122285615fe7d08)
  - Fix blank screen occuring in some cases.
  - Initial RS600 support.
  - Sync and LUT fixes.
  - Add useful DPI calculation.
- Relax xorg-x11-server-utils requirement: Only for F-8 and later, no %%{dist}.

* Fri Nov 30 2007 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.0.0-0.1.20071130git
- New snapshot (upstream commit 9fe776edf44c40d06e0059878df4f37391409c66 aka 1.0.0)
  - Significantly improve README and radeonhd(4) man page.
  - Add a number of connector table workarounds.
  - Several messages fixed or toned down.

* Thu Nov 29 2007 Hans Ulrich Niedermann <hun@n-dimensional.de> - 0.0.4-0.2.20071129git
- New snapshot (upstream commit 8b1b8bfb21d2d86780cb4e02abc813578daa24bd):
  - RandR 1.2 support with hotplugging of monitors.
  - R600 LVDS: RS690M, M72, M74 and M76 devices.
  - Fixed "white screen" bug.
  - Numerous fixes and new support for features.
- Preserve source file timestamps where possible.

* Fri Nov 16 2007 Hans Ulrich Niedermann <hun@n-dimensional.de> - 0.0.2-0.18.20071116git
- New snapshot (upstream commit dbb073b8b314264e311c3a1ebecd13d93e9627a6):
  - Macbook Pro PCI ID based workaround for awkward AtomBIOS connector table.
  - TMDSA: create a table for electrical adjustments.
- Fix bug submission URL in README.fedora.

* Tue Nov 13 2007 Hans Ulrich Niedermann <hun@n-dimensional.de> - 0.0.2-0.17.20071113git
- New snapshot (upstream commit 6f1800ca52531f5baf3df2e65a7bbd93e4b1e637):
  - LVTMA TMDS: Add initial TMDS support for r5xx.
  - TMDS B: Add table with macro control values.
- Loosen requirements on xorg-x11-server-{Xorg,sdk} from 1.3 to 1.1 (FC6, EL5).
- Require pkgconfig for building (not in EL5 default buildroot).
- Adapt references to rhd_conntest in filesystem.
- Fix git:// URL in README.fedora.

* Sun Nov 11 2007 Hans Ulrich Niedermann <hun@n-dimensional.de> - 0.0.2-0.16.20071105git
- Updated README.fedora.
- Improved git commit log message.
- First F-7 and F-8 builds.

* Mon Nov 05 2007 Hans Ulrich Niedermann <hun@n-dimensional.de> - 0.0.2-0.15.20071105git
- New snapshot (upstream commit e9c24f662860229440dc61ecbae22e7d7c74d442):
  - Improve online help in rhd_conntest.
  - Use correct variable for DDC speed setting on R6xx, fix some warnings.
  - Add git version to program output (we emulate that).
  - Ship rhd_conntest source, and build it (we also install it).

* Tue Oct 31 2007 Hans Ulrich Niedermann <hun@n-dimensional.de> - 0.0.2-0.14.20071031git
- New snapshot (upstream commit ad599c4436c64b11d18c89da6a684f5241979a96):
  - Fix 1650Pro PLL gain control.
  - Improve connector handling.
- Stow away radeonhd.xinf generator for possible later use.

* Tue Oct 30 2007 Hans Ulrich Niedermann <hun@n-dimensional.de> - 0.0.2-0.13.20071030git
- Do not #include <sys/io.h> in rhd_conntest.c (fix PPC build).

* Tue Oct 30 2007 Hans Ulrich Niedermann <hun@n-dimensional.de> - 0.0.2-0.12.20071030git
- New snapshot (upstream commit f3a2530cea981c6b4c88ec85093032ea152ed47f):
  - #include standard headers in corner cases (supposed to fix FC6 build)

* Sun Oct 28 2007 Hans Ulrich Niedermann <hun@n-dimensional.de> - 0.0.2-0.11.20071028git
- New snapshot (upstream commit 604bfb02cefa5f56b40aea2dc3256f09836121a4):
  - Added ID for Radeon HD 2600 LE (RV630).
  - Be smarter about the xorg.conf monitor section by selectively ignoring it.
  - Fix mode instability when returning to VT on some mobilities.

* Thu Oct 25 2007 Hans Ulrich Niedermann <hun@n-dimensional.de> - 0.0.2-0.10.20071025git
- New snapshot (upstream commit d8cb8a2a8315f86fae0266f58ee30b609c81d510).
- Remove man page patches (man page is upstream now).

* Tue Oct 23 2007 Hans Ulrich Niedermann <hun@n-dimensional.de> - 0.0.2-0.9.20071023git
- New snapshot (upstream commit 8699deaba2c920a3df35acfea49360888868becb).
- Add bug report section to README.fedora.

* Sat Oct 20 2007 Hans Ulrich Niedermann <hun@n-dimensional.de> - 0.0.2-0.8.20071020git
- New snapshot (upstream commit 3579bdddd95dc6f129e57bcf05cbd8b9b375940f).
- Cleaned up snapshot script.
- Package rhd_conntest utility when building snapshot package.
- Add simple man page.
- Add README.fedora file.

* Wed Oct 17 2007 Hans Ulrich Niedermann <hun@n-dimensional.de> - 0.0.2-0.7.20071017git
- New snapshot (upstream commit d03841b4950b3b827b3c42507e01767d0569391f).
- Use upstream's version 0.0.2.
- Trade in ThinkPad backlight key fix for non-broken mode on lid event.

* Mon Oct 15 2007 Hans Ulrich Niedermann <hun@n-dimensional.de> - 0.0.1-0.6.20071015git
- Hard-code version at 0.0.1 until upstream have figured out what they want.
- Names of snapshot tarballs now contain timestamp.
- Static definition of %%{date}, optionally updated by snapshot script.
- Non-executable snapshot script.

* Mon Oct 15 2007 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.1.1-0.5.20071015git
- Use %%{driverdir} where possible.
- Include xorg-x11-drv-radeonhd-snapshot.sh script in SRPM.
- Trimmed Description.
- Removed unnecessary -n from %%files.
- Removed ".fc8" from changelog entries.
- Improved comment on %%define snapshot.

* Mon Oct 15 2007 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.1.1-0.4.20071015git
- New snapshot (needs less patches).

* Sun Oct 14 2007 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.1.1-0.3.20071014git
- Initial Fedora RPM package.
